var http = require('http');
var fs = require('fs');
var url = require('url');
var sockjs = require('sockjs');
var crypt = require('crypto');
var ini = require('ini');
var path = require('path');

/* Config parsing begins */

// Default Config
var isLog = true;

var HTTP_PORT = 8125;
var HTTPS_SOCK_PORT = 8126;
var HTTP_SOCK_PORT = 8127;

var isHasPhpTrigger = false;
var php = '';
var outputtime = '';

var privateKey, certificate, intermediate1, intermediate2;

var config_file = path.resolve(__dirname, 'config.ini');
if (fs.existsSync(config_file)) {
	var config = ini.parse(fs.readFileSync(config_file, 'utf-8'));

	if (config.listener && config.listener.port) {
		HTTP_PORT = config.listener.port;
	}

	if (config.socket && config.socket.https_port) {
		HTTPS_SOCK_PORT = config.socket.https_port;
	}
	if (config.socket && config.socket.http_port) {
		HTTP_SOCK_PORT = config.socket.http_port;
	}

	if (config.php_process && config.php_process.exe && config.php_process.file) {
		isHasPhpTrigger = true;

		php = config.php_process.exe;
		outputtime = config.php_process.file;
	}

	if (config.ssl) {
		privateKey = config.ssl.privateKey;
		certificate = config.ssl.certificate;
		intermediate1 = config.ssl.intermediate1;
		intermediate2 = config.ssl.intermediate2;
	}
}

/* Config parsing end */

var event = require('events');
var wallRoom = new event.EventEmitter();
var userRoom = new event.EventEmitter();

// Set max listener to 0 for unlimited, other wise it will raise Memory leak warning error.
wallRoom.setMaxListeners(0);
userRoom.setMaxListeners(0);

var group_prefix = 'grp_';
var user_prefix = 'usr_';

// wallRoom.removeAllListeners();
// wallRoom.removeListener("all");
// wallRoom.removeListener("all", foo);

var toSha256 = function (str) {
	return crypt.createHash('sha256').update(str, 'utf8').digest('hex');
};
var isValidUser = function (entity_id, user_id, uid_sha256) {
	return true;
	if (!entity_id || !user_id || !uid_sha256) {
		return false;
	}

	var salt = uid_sha256.substr(0, 8);
	var hash = (salt + toSha256(salt + entity_id + user_id)).substr(0, 32);

	return (hash == uid_sha256);
};

/* OUM notification php execution begins */
var trigger_notification = null;

if (isHasPhpTrigger) {
	var child_process = require('child_process');

	var execFile = child_process.execFile;
	trigger_notification = function (message) {
		if (!message) {
			return false;
		}
		var proc = execFile(php, [outputtime, 'home', 'notification', message], function (error, stdout, stderr) {
			console.log(error, stdout, stderr);
		});
	};
}
/* OUM notification php execution end */

/* To Browser SockJS Conn begin */
var sock = sockjs.createServer();
sock.on('connection', function (conn) {

	isLog && console.log("New Connection : ", conn.remoteAddress, conn.remotePort);

	var timer = setTimeout(function () {
		conn.close();
	}, 1000 * 5);	// 5 Second wait.

	var wallRoomEventName = "";
	var wallRoomHandler = function (query) {
		isLog && console.log("Group Room : ", query);
		conn.write(JSON.stringify(query));
	};

	var userRoomEventName = "";
	var userRoomHandler = function (query) {
		isLog && console.log("User Room : ", query);
		conn.write(JSON.stringify(query));
	};

	conn.on('subscribe', function (message) {
		isLog && console.log(message);
	});

	conn.on('data', function (message) {
		isLog && console.log("New Data : ", message);

		if (!message) {
			return false;
		}
		message = JSON.parse(message);
		if (!message.event) {
			return false;
		}

		switch (message.event) {
			case 'subscribe_wall':
			case 'subscribe_all':
				// Clear the setTimeout for avoid auto closing connection.
				clearTimeout(timer);
				timer = 0;

				// Remove old listener before subscribe to new listener.
				wallRoom.removeListener(wallRoomEventName, wallRoomHandler);

				// New Event Name.
				wallRoomEventName = group_prefix + message.entity_id + '_' + message.wall_type;

				// Subscribe to WallRoom Event.
				wallRoom.on(wallRoomEventName, wallRoomHandler);

				break;
			case 'subscribe_user':
				// Clear the setTimeout for avoid auto closing connection.
				clearTimeout(timer);
				timer = 0;

				if (!isValidUser(message.entity_id, message.user_id, message.uid)) {
					isLog && console.log("Invalid data : ", message);
					conn.close();
					break;
				}

				userRoomEventName = user_prefix + message.entity_id + '_' + message.user_id;

				// Subscribe to UserRoom Event.
				userRoom.on(userRoomEventName, userRoomHandler);
				break;
		}
	});

	conn.on('close', function () {
		// Code here for unsubscribe to event.

		wallRoom.removeListener(wallRoomEventName, wallRoomHandler);
		userRoom.removeListener(userRoomEventName, userRoomHandler);

		isLog && console.log("Connection Closed !!!");
	});
});

if (fs.existsSync(privateKey)) {
	var https = require('https');

	privateKey = fs.readFileSync(privateKey, 'utf8');
	certificate = fs.readFileSync(certificate, 'utf8');
	intermediate1 = fs.readFileSync(intermediate1, 'utf8');
	// var intermediate1 = fs.readFileSync(path + '/intermediate1.crt', 'utf8');
	// var intermediate2 = fs.readFileSync(path + '/ssl/intermediate2.crt', 'utf8');
	var credentials = {
		key: privateKey,
		cert: certificate,
		ca: intermediate1// [intermediate1, intermediate2]
	};

	var https_sock_server = null;
	https_sock_server = https.createServer(credentials);
	sock.installHandlers(https_sock_server, { prefix: '/notification' });
	https_sock_server.listen(HTTPS_SOCK_PORT, '0.0.0.0');
	console.log("Browser https socket listening on : ", HTTPS_SOCK_PORT);
}

var sock_server = http.createServer();
sock.installHandlers(sock_server, { prefix: '/notification' });
sock_server.listen(HTTP_SOCK_PORT, '0.0.0.0');

console.log("Browser http socket listening on : ", HTTP_SOCK_PORT);

/* To Browser end */

/* Trigger from server */

// http://localhost:8000/?name=pandi&age=25

/*
	Handle PHP request.
	Which is called from php onSave ( post/comments/like/unlike )
*/
function handleRequest(request, response) {
	var url_parts = url.parse(request.url, true);
	var query = url_parts.query;

	isLog && console.log("New Trigger : ", query);

	if (!query) {
		response.writeHead(200, { 'Content-Type': 'application/json' });
		response.end('[0, "Invalid data passed"]');
		return false;
	}

	if (query.oum && trigger_notification) {
		trigger_notification(query.msg);
	}
	else if (query.users) {
		// var userRoomEventName	= "";
		for (var i = 0, usrs = query.users.split(","), iLen = usrs.length; i < iLen; i++) {
			userRoom.emit(user_prefix + query.entity_id + '_' + usrs[i], query);
		}
	}
	else if (query.wall_type) {
		// Publish to all connections.
		// query.wall_type will have the "all", project_id (group_id)
		// wallRoom.emit(group_prefix + query.entity_id + '_' + query.wall_type, query);
		wallRoom.emit(group_prefix + query.entity_id + '_all', query);
	}

	response.writeHead(200, { 'Content-Type': 'application/json' });
	// response.end(JSON.stringify([1, "Success"]));
	response.end('[1,"Success"]');
}

var server = http.createServer(handleRequest);

server.listen(HTTP_PORT, function () {
	console.log("Server listening on: http://localhost:%s", HTTP_PORT);
});
/* Trigger from server */

